@@ -805,7 +805,10 @@ int output_speak(TSpeechDMessage * msg, OutputModule *output)
 		MSG(2, "Invalid message type in output_speak()!");
 	}
 
-	SEND_DATA(msg->buf);
+	if (!strcmp(msg->buf, " "))
+		SEND_DATA("space");
+	else
+		SEND_DATA(msg->buf);
 	SEND_CMD("\n.");
 
 	/* Start a thread that will process the module events */
@@ -991,6 +994,8 @@ static int output_module_is_speaking(OutputModule * output)
 				MSG(4, "we sent PAUSE too late, now tell the speak queue");
 				if (!output_pause_queued)
 					module_speak_queue_pause();
+				if (!module_speak_queue_add_end())
+					MSG(3, "Warning: couldn't add end to speak queue");
 			} else {
 				if (!module_speak_queue_add_end())
 					MSG(3, "Warning: couldn't add end to speak queue");
@@ -1020,6 +1025,8 @@ static int output_module_is_speaking(OutputModule * output)
 		if (output->audio) {
 			if (!output_pause_queued)
 				module_speak_queue_pause();
+			if (!module_speak_queue_add_end())
+				MSG(3, "Warning: couldn't add end to speak queue");
 		} else
 			module_report_event_pause();
 		retcode = 0;
